<?php
/**
 * Custom template tags for Wild Book
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @since Wild Book 1.0
 */

if ( ! function_exists( '_wp_render_title_tag' ) ) :
  /**
   * Add wp_title on head if theme not supported "title-tag" feature.
   *
   * @since Wild Book 1.0
   */
  function wdb_render_title() {
  ?>
    <title><?php wp_title( '|', true, 'right' ); ?></title>
  <?php
  }

  add_action( 'wp_head', 'wdb_render_title' );
endif;

if ( ! function_exists( 'wdb_site_title' ) ) :
  /**
   * Prints HTML with blog title and description.
   *
   * @since Wild Book 1.0
   */
  function wdb_site_title() {
    if( get_theme_mod( 'display_site_title', 1 ) ) {
      printf( '<%1$s class="site-title"><a href="%2$s" rel="home">%3$s</a></%1$s>', 
        is_front_page() && is_home() ? 'h1' : 'p', 
        esc_url( home_url( '/' ) ), 
        esc_html( get_bloginfo( 'name' ) ) 
      );
    }
    
    $tagline = get_theme_mod( 'tagline' );

    if( $tagline ) {
      $tagline = wp_kses( $tagline, array(
          'a' => array(
            'href' => array(),
            'title' => array(),
            'target' => array()
          ),
          'b'      => array(),
          'strong' => array(),
          'em'     => array(),
          'i'      => array(),
          'img' => array(
            'src' => array(),
            'alt' => array(),
            'title' => array()
          ),
          'span' => array(),
          'br' => array(),
          'p'  => array()
        )
      );
    }

    if( $tagline || is_customize_preview() ) {
      printf( '<div class="tagline">%s</div>', $tagline );
    }
  }
endif;

if ( ! function_exists( 'wdb_site_logo' ) ) :
  /**
   * Prints HTML with blog logo image.
   *
   * @since Wild Book 1.4.5
   */
  function wdb_site_logo() {
    if( get_header_image() ) {
      printf( '<div class="header-image%s"><a href="%s" rel="home"><img src="%s" height="%s" width="%s" alt="%s" /></a></div>', 
        get_theme_mod( 'header_image_rounded' ) ? ' rounded' : '', 
        esc_url( get_theme_mod( 'logo_link_url' ) ? get_theme_mod( 'logo_link_url' ) : home_url( '/' ) ), 
        apply_filters( 'wdb_header_image', get_header_image() ), 
        esc_attr( get_custom_header()->height ), 
        esc_attr( get_custom_header()->width ), 
        esc_attr( get_bloginfo( 'title' ) ) 
      );
    }
  }
endif;

if ( ! function_exists( 'wdb_social_profiles' ) ) :
  /**
   * Prints HTML with social profiles buttons.
   *
   * @since Wild Book 1.0
   */
  function wdb_social_profiles( $before = '', $after = '' ) {
    $social_profiles = get_theme_mod( 'social' );
    
    if( empty( $social_profiles ) )
      return;
    
    $output = '';
    
    $target_blank = get_theme_mod( 'target_blank', 1 );
    $nofollow = get_theme_mod( 'nofollow', 0 );
    
    if( is_array( $social_profiles ) ) {
      foreach( $social_profiles as $network_id => $url ) {
        if( $url )
          $output .= sprintf( 
            '<a href="%1$s" class="%4$s" %2$s %3$s><i class="fa fa-%4$s"></i></a>', 
            ( $network_id == 'email' ) ? 'mailto:' . esc_attr( $url ) : esc_url( $url ), 
            $target_blank ? 'target="_blank"' : '',
            $nofollow ? 'rel="nofollow"' : '',
            esc_attr( $network_id ) 
         );
      }
    }
    
    if( $output )
      printf( '%s<div class="social-profiles">%s</div>%s', $before, $output, $after );
  }
endif;

if ( ! function_exists( 'wdb_site_copyright' ) ) :
  /**
   * Prints HTML with custom or default copyright text.
   *
   * @since Wild Book 1.0
   */
  function wdb_site_copyright( $before = '', $after = '' ) {
    $default_copyright = sprintf( '&copy; %1$d <a href="%2$s">%3$s</a>', date('Y'), esc_url( home_url( '/' ) ), esc_html( get_bloginfo( 'name' ) ) );
    $copyright = get_theme_mod( 'copyright' );
    
    if( $copyright ) {
      $copyright = wp_kses( $copyright, array(
          'a' => array(
            'href' => array(),
            'title' => array(),
            'target' => array()
          ),
          'b'      => array(),
          'strong' => array(),
          'em'     => array(),
          'i'      => array(),
          'img' => array(
            'src' => array(),
            'alt' => array(),
            'title' => array()
          ),
          'span' => array(),
          'br' => array(),
          'p'  => array()
        )
      );
    }
    
    printf( '%s%s%s', $before, $copyright ? $copyright : $default_copyright, $after );
  }
endif;

if ( ! function_exists( 'wdb_post_thumbnail' ) ) :
  /**
   * Display an optional post thumbnail.
   *
   * Wraps the post thumbnail in an anchor element on index views, or a div
   * element when on single views.
   *
   * @since Wild Book 1.0
   * @source Twenty Fifteen 1.0
   */
  function wdb_post_thumbnail() {

    $display_post_thumbnail_archive = ( ! metadata_exists( 'post', get_the_id(), 'display_post_thumbnail_archive' ) ) ? true : get_post_meta( get_the_id(), 'display_post_thumbnail_archive', true );
    $display_post_thumbnail = ( ! metadata_exists( 'post', get_the_id(), 'display_post_thumbnail' ) ) ? true : get_post_meta( get_the_id(), 'display_post_thumbnail', true );

    if( ! is_single() && ! $display_post_thumbnail_archive && ! is_search() ) {
      return;
    }
    
    if( is_single() && ! $display_post_thumbnail ) {
      return;
    }
    
    if ( post_password_required() || is_attachment() || ! has_post_thumbnail()  ) {
      return;
    }

    $thumbnail_size = get_theme_mod( 'thumbnail_hard_crop', 1 ) ? 'post-thumbnail' : 'post-thumbnail-not-crop';
    
    $thumbnail_caption = get_post( get_post_thumbnail_id() )->post_excerpt;

    if ( is_singular() ) :
    ?>

    <div class="post-thumbnail<?php if( $thumbnail_caption ) : ?> has-caption<?php endif; ?>">
      <?php the_post_thumbnail( $thumbnail_size ); ?>
    </div><!-- .post-thumbnail -->

    <?php else : ?>

    <a class="post-thumbnail<?php if( $thumbnail_caption ) : ?> has-caption<?php endif; ?>" href="<?php the_permalink(); ?>" aria-hidden="true">
      <?php
        the_post_thumbnail( is_search() ? 'medium-thumbnail' : $thumbnail_size , array( 'alt' => get_the_title() ) );
      ?>
    </a>

    <?php endif; // End is_singular()
    
    if( $thumbnail_caption && ! is_search() ) {
      printf( '<div class="wp-caption-text post-thumbnail-caption">%s</div>', $thumbnail_caption );
    }
  }
endif;

if ( ! function_exists( 'wdb_entry_meta' ) ) :
  /**
   * Prints HTML with meta information for the categories, post date.
   *
   * @since Wild Book 1.0
   */
  function wdb_entry_meta( $before = '', $after = '' ) {
    if ( ! $post = get_post() )
      return;
  
    $output = '';
    $post_type = get_post_type();
    
    if ( in_array( $post_type, array( 'post', 'attachment' ) ) && get_theme_mod( 'display_date', 1 ) ) {
      $time_string = sprintf( '<time class="entry-date published updated" datetime="%1$s">%2$s</time>', esc_attr( get_the_date( 'c' ) ), get_the_date() );
      $time_string = sprintf( esc_html_x( 'Posted on %s', 'Post date', 'wildbook' ), $time_string );

      $output .= sprintf( '<span class="posted-on post-meta">%s</span>', $time_string );
    }

    if ( 'post' == get_post_type() && ( is_multi_author() || get_theme_mod( 'display_author_name', 0 ) ) ) {
      $author_string = sprintf( '<a class="url fn n" href="%s">%s</a>', esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ), get_the_author() );
      $author_string = sprintf( esc_html_x( 'by %s', 'Post author', 'wildbook' ), $author_string );
    
      $output .= sprintf( '<span class="byline post-meta"><span class="author vcard">%s</span></span>', $author_string );
    }
    
    if ( 'post' == get_post_type() && get_theme_mod( 'display_comments_number', 0 ) && comments_open( $post->ID ) ) {
      $output .= sprintf( '<span class="comments-number post-meta"><a href="%s">%s</a></span>', get_comments_link( $post->ID ), get_comments_number_text() );
    }
    
    if( 'portfolio' == get_post_type() && taxonomy_exists( 'portfolio_category' ) ) {
      $portfolio_cats = get_the_term_list( $post->ID, 'portfolio_category', '', ', ', '' );
      
      if( $portfolio_cats ) {
        $output .= sprintf( '<span class="portfolio-cats post-meta">%s</span>', $portfolio_cats );
      }
    }

    if( $output )
      printf( '%s%s%s', $before, $output, $after );
  }
endif;

if ( ! function_exists( 'wdb_entry_footer' ) ) :
  /**
   * Prints HTML with share buttons and tags after post content.
   *
   * @since Wild Book 1.4.8
   */
  function wdb_entry_footer( $before = '', $after = '' ) {
    if ( ! $post = get_post() )
      return;

    $output = '';

    if( is_single() && get_theme_mod( 'display_tags_list', 1 ) ) {
      if( 'post' == $post->post_type )
        $output .= get_the_tag_list( '<div class="tags-list">', '', '</div>' );

      if( 'portfolio' == $post->post_type && taxonomy_exists( 'portfolio_tag' ) )
        $output .= get_the_term_list( $post->ID, 'portfolio_tag', '<div class="tags-list">', '', '</div>' );
    } 

    if( get_theme_mod( 'display_share_buttons', 1 ) && ! wdb_has_more() && ! is_page() ) {
      $output .= wdb_get_share_buttons();
    }

    if( is_page() ) {
      $page_options = get_post_meta( $post->ID, 'wdb_page_options', true );
      
      if( get_theme_mod( 'display_page_share_buttons', 1 ) && ( isset( $page_options['display_share_buttons'] ) ? $page_options['display_share_buttons'] : true ) ) {
        $output .= wdb_get_share_buttons();
      }
    }

    if( $output )
      printf( '%s%s%s', $before, $output, $after );
  }
endif;

if ( ! function_exists( 'wdb_categories_list' ) ) :
  /**
   * Prints HTML with post categories list.
   *
   * @since Wild Book 1.0
   */
  function wdb_categories_list() {
    if( get_theme_mod( 'display_categories', 1 ) ) {
      $categories_list = get_the_category_list( esc_attr_x( ', ', 'Used between list items, there is a space after the comma.', 'wildbook' ) );
      if ( $categories_list ) {
        printf( '<span class="cat-links">%s</span>', $categories_list );
      }
    }
  }
endif;

/**
 * Get HTML with post share buttons.
 *
 * @since Wild Book 1.0
 */
function wdb_get_share_buttons() {
  $post = get_post();

  if( !$post )
    return;

  $thumbnail_src = '';
  $thumbnail = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), 'post-thumbnail' );
  
  if( $thumbnail )
    $thumbnail_src = urlencode( esc_url( $thumbnail['0'] ) );

  $post_permalink = urlencode( esc_url( get_permalink( $post->ID ) ) );
  $title          = urlencode( strip_tags( get_the_title() ) );
  $excerpt        = urlencode( strip_tags( get_the_excerpt() ) );
  
  $buttons = array(
  	'vk' => array(
      'url'    => 'http://vk.com/share.php?url=' . $post_permalink . '&amp;title=' . $title . '&amp;description=' . $excerpt . '&amp;image=' . $thumbnail_src,
      'title'  => esc_html__( 'Share on Vkontakte', 'wildbook' ),
      'icon'   => '<i class="fa fa-vk"></i>',
      'show'   => false
     ),
    'facebook' => array(
      'url'    => 'http://www.facebook.com/sharer/sharer.php?u=' . $post_permalink,
      'title'  => esc_html__( 'Share on Facebook', 'wildbook' ),
      'icon'   => '<i class="fa fa-facebook"></i>',
      'show'   => true
     ),
    'twitter' => array(
      'url'    => 'https://twitter.com/intent/tweet?text=' . $title . '&amp;url=' . $post_permalink,
      'title'  => esc_html__( 'Tweet It', 'wildbook' ),
      'icon'   => '<i class="fa fa-twitter"></i>',
      'show'   => true
     ),
    'google' => array(
      'url'    => 'https://plus.google.com/share?url=' . $post_permalink,
      'title'  => esc_html__( 'Share on Google Plus', 'wildbook' ),
      'icon'   => '<i class="fa fa-google-plus"></i>',
      'show'   => true
     ),
    'pinterest' => array(
      'url'    => 'https://www.pinterest.com/pin/create/button/?description=' . $title . '&amp;media=' . $thumbnail_src . '&amp;url=' . $post_permalink,
      'title'  => esc_html__( 'Pin It', 'wildbook' ),
      'icon'   => '<i class="fa fa-pinterest-p"></i>',
      'show'   => true
     ),
    'tumblr' => array(
      'url'    => 'http://www.tumblr.com/share/link?url=' . $post_permalink . '&amp;name=' . $title . '&amp;description=' . $excerpt,
      'title'  => esc_html__( 'Share on Tumblr', 'wildbook' ),
      'icon'   => '<i class="fa fa-tumblr"></i>',
      'show'   => true
     )
  );
  
  $output = '';

  foreach( $buttons as $button_id => $button_data ) {
    if( get_theme_mod( 'display_' . $button_id . '_share_button', $button_data['show'] ) ) {
      $output .= sprintf( '<a href="%s" title="%s" class="share-button wdb-%s-button" rel="nofollow">%s</a>', esc_url( $button_data['url'] ), esc_attr( $button_data['title'] ), esc_attr( $button_id ), $button_data['icon'] );
    }
  } 
  
  if( $output )
    return sprintf( '<div class="share-buttons">%s</div>', $output );
}

if ( ! function_exists( 'wdb_share_buttons' ) ) :
  /**
   * Prints HTML with post share buttons.
   *
   * @since Wild Book 1.0
   */
  function wdb_share_buttons( $before = '', $after = '' ) {
    printf( '%s%s%s', $before, wdb_get_share_buttons(), $after );
  }
endif;

if ( ! function_exists( 'wdb_related_posts' ) ) :
  /**
   * Related posts for current post.
   *
   * @since Wild Book 1.0
   */
  function wdb_related_posts( $before = '', $after = '' ) {
    global $post;
    
    if( !$post )
      return;

    if( $post->post_type !== 'post' )
      return;
      
    $query_args = array(
      'post__not_in'        => array( $post->ID ),
      'posts_per_page'      => 3,
      'ignore_sticky_posts' => true
    );
    
    $related_by = get_theme_mod( 'related_by', 'none' );
    
    switch ( $related_by ) {
      case 'category' :
        $categories = get_the_category( $post->ID );
        if ( $categories ) {
          $category_ids = array();
          foreach( $categories as $category ) 
            $category_ids[] = $category->term_id;
            
          $query_args['category__in'] = $category_ids;
        }
        break;
      
      case 'tags' :
        $tags = wp_get_post_tags( $post->ID );
        if ( $tags ) {
          $tag_ids = array();
          foreach( $tags as $tag ) 
            $tag_ids[] = $tag->term_id;
            
          $query_args['tag__in'] = $tag_ids;
        }
        break;
      case 'none' :
        $query_args['orderby'] = 'rand';
        break;
    }
    
    $related_posts = new WP_Query( $query_args );
    $output = '';
    
    if( $related_posts->have_posts() ) {
      printf( '%s<div class="related-posts flex-row flex-3c">', $before );
      
      while( $related_posts->have_posts() ) : $related_posts->the_post(); ?>
      <div class="related-post flex-item<?php if( has_post_thumbnail() ) : ?> has-post-thumbnail<?php endif; ?>">
      
        <?php if( has_post_thumbnail() ) : ?>
        <a href="<?php the_permalink()?>" class="post-thumbnail" rel="bookmark" title="<?php the_title(); ?>">
          <?php the_post_thumbnail( 'medium-thumbnail' ); ?>
        </a>
        <?php endif; ?>
        
        <div class="related-post-content">
          <a href="<?php the_permalink(); ?>" rel="bookmark" title="<?php the_title(); ?>"><?php the_title(); ?></a>
          <?php printf( '<div class="post-meta">%s</div>', get_the_date() ); ?>
        </div>
      </div>
    <?php 
      endwhile;
      
      printf( '</div>%s', $after );
    }

    wp_reset_postdata(); 
  }
endif;

/**
 * Check if post has more tag.
 *
 * @since Wild Book 1.0
 */
function wdb_has_more() {
  global $post;
  
  if( is_singular() )
    return false;
  
  if( strpos( $post->post_content, '<!--more-->' ) )
    return true;
  
  return false;
}

if ( ! function_exists( 'wdb_content_section' ) ) :
  /**
   * Prints HTML with custom content.
   *
   * @since Wild Book 1.6
   */
  function wdb_content_section( $location = '', $before = '', $after = '' ) {
    if( ! $location )
      return;

    $custom_content_page_id = absint( get_theme_mod( $location . '_content_page_id' ) );
    $output = '';

    if( $custom_content_page_id ) {
      $custom_content_page = get_post( $custom_content_page_id );

      if( $custom_content_page ) {
        $custom_content_page_content = apply_filters( 'the_content', $custom_content_page->post_content );
        $custom_content_page_content = str_replace( ']]>', ']]&gt;', $custom_content_page_content );

        if( $custom_content_page_content )
          $output .= $custom_content_page_content;
      }
    }

    if( $output ) 
      printf( '%s%s%s', $before, $output, $after );
  }
endif;
?>